@@ -28,7 +28,10 @@ example_model <- function(topic, envir = parent.frame(), silent = FALSE) {
     return(names(example_cache))
   }
   assert_character(topic)
-  assert_that(topic %in% names(example_cache), msg = "Unkown example. For a list of examples call example_model().")
+  assert_that(
+    topic %in% names(example_cache),
+    msg = "Unkown example. For a list of examples call example_model()."
+  )
   ex_str <- example_cache[[topic]]
   if (silent) {
     ex_str <- c("suppressMessages(capture.output({ ", ex_str, "}))")
